#![no_std]
#![no_main]
#![feature(type_alias_impl_trait)]

use defmt::*;
use embassy_executor::Spawner;
use embassy_rp::{gpio, peripherals, watchdog::Watchdog};
use embassy_time::{Duration, Timer};
use gpio::{Level, Output};
use {defmt_rtt as _, panic_probe as _};
use heizung as _;  // for clear_bootloader_state
use heizung::watchdog::WatchdogFixed;

#[embassy_executor::task]
async fn dogfeeder(watchdog: peripherals::WATCHDOG) {
    WatchdogFixed::new(watchdog).start_and_feed_continuously().await;
}

#[embassy_executor::main]
async fn main(spawner: Spawner) {
    let p = embassy_rp::init(Default::default());
    let mut led = Output::new(p.PIN_4, Level::Low);

    unwrap!(spawner.spawn(dogfeeder(p.WATCHDOG)));

    loop {
        info!("led on!");
        led.set_high();
        Timer::after(Duration::from_secs(1)).await;

        info!("led off!");
        led.set_low();
        Timer::after(Duration::from_secs(1)).await;
    }
}
